﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.BioBoost.Representation;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using System;

namespace HeuristicLab.BioBoost.Views {

  [StorableClass]
  public class RegionDetailData : ParameterizedNamedItem {

    public override bool CanChangeName { get { return false; } }

    #region Parameters
    public ValueParameter<BioBoostCompoundSolution> SolutionParameter {
      get { return (ValueParameter<BioBoostCompoundSolution>) Parameters["Solution"]; }
    }
    public ValueParameter<StringValue> RegionNameParameter {
      get { return (ValueParameter<StringValue>) Parameters["RegionName"]; }
    }
    #endregion

    #region Parameter Values
    public BioBoostCompoundSolution Solution {
      get { return SolutionParameter.Value; }
      set { SolutionParameter.Value = value;  }
    }
    public String RegionName {
      get { return RegionNameParameter.Value.Value; }
      set { RegionNameParameter.Value.Value = value; }
    }
    #endregion

    [StorableConstructor]
    protected RegionDetailData(bool isDeserializing) : base(isDeserializing) {}
    protected RegionDetailData(RegionDetailData orig, Cloner cloner) : base(orig, cloner) {}
    public RegionDetailData() {
      Parameters.Add(new ValueParameter<BioBoostCompoundSolution>("Solution", "The solution from which the detail should be obtained."));
      Parameters.Add(new ValueParameter<StringValue>("RegionName", "The name of the region for which details show be displayed."));
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new RegionDetailData(this, cloner);
    }

  }
}
